@@ -22,6 +22,7 @@ ALL_ROUTES = [
     ('account:item-detail', 'SoftLayer.CLI.account.item_detail:cli'),
     ('account:cancel-item', 'SoftLayer.CLI.account.cancel_item:cli'),
     ('account:orders', 'SoftLayer.CLI.account.orders:cli'),
+    ('account:bandwidth-pools', 'SoftLayer.CLI.account.bandwidth_pools:cli'),
 
     ('virtual', 'SoftLayer.CLI.virt'),
     ('virtual:bandwidth', 'SoftLayer.CLI.virt.bandwidth:cli'),
@@ -103,6 +104,8 @@ ALL_ROUTES = [
     ('block:snapshot-create', 'SoftLayer.CLI.block.snapshot.create:cli'),
     ('block:snapshot-delete', 'SoftLayer.CLI.block.snapshot.delete:cli'),
     ('block:snapshot-disable', 'SoftLayer.CLI.block.snapshot.disable:cli'),
+    ('block:snapshot-set-notification', 'SoftLayer.CLI.block.snapshot.set_notify_status:cli'),
+    ('block:snapshot-get-notification-status', 'SoftLayer.CLI.block.snapshot.get_notify_status:cli'),
     ('block:snapshot-enable', 'SoftLayer.CLI.block.snapshot.enable:cli'),
     ('block:snapshot-schedule-list', 'SoftLayer.CLI.block.snapshot.schedule_list:cli'),
     ('block:snapshot-list', 'SoftLayer.CLI.block.snapshot.list:cli'),
@@ -148,6 +151,8 @@ ALL_ROUTES = [
     ('file:snapshot-delete', 'SoftLayer.CLI.file.snapshot.delete:cli'),
     ('file:snapshot-disable', 'SoftLayer.CLI.file.snapshot.disable:cli'),
     ('file:snapshot-enable', 'SoftLayer.CLI.file.snapshot.enable:cli'),
+    ('file:snapshot-set-notification', 'SoftLayer.CLI.file.snapshot.set_notify_status:cli'),
+    ('file:snapshot-get-notification-status', 'SoftLayer.CLI.file.snapshot.get_notify_status:cli'),
     ('file:snapshot-schedule-list', 'SoftLayer.CLI.file.snapshot.schedule_list:cli'),
     ('file:snapshot-list', 'SoftLayer.CLI.file.snapshot.list:cli'),
     ('file:snapshot-order', 'SoftLayer.CLI.file.snapshot.order:cli'),
@@ -204,6 +209,7 @@ ALL_ROUTES = [
     ('loadbal:health', 'SoftLayer.CLI.loadbal.health:cli'),
     ('loadbal:member-add', 'SoftLayer.CLI.loadbal.members:add'),
     ('loadbal:member-del', 'SoftLayer.CLI.loadbal.members:remove'),
+    ('loadbal:l7policies', 'SoftLayer.CLI.loadbal.layer7_policy_list:policies'),
     ('loadbal:pool-add', 'SoftLayer.CLI.loadbal.pools:add'),
     ('loadbal:pool-edit', 'SoftLayer.CLI.loadbal.pools:edit'),
     ('loadbal:pool-del', 'SoftLayer.CLI.loadbal.pools:delete'),
@@ -272,6 +278,7 @@ ALL_ROUTES = [
     ('hardware:dns-sync', 'SoftLayer.CLI.hardware.dns:cli'),
     ('hardware:storage', 'SoftLayer.CLI.hardware.storage:cli'),
     ('hardware:upgrade', 'SoftLayer.CLI.hardware.upgrade:cli'),
+    ('hardware:sensor', 'SoftLayer.CLI.hardware.sensor:cli'),
 
     ('securitygroup', 'SoftLayer.CLI.securitygroup'),
     ('securitygroup:list', 'SoftLayer.CLI.securitygroup.list:cli'),
@@ -348,6 +355,7 @@ ALL_ROUTES = [
 
     ('vlan', 'SoftLayer.CLI.vlan'),
     ('vlan:create', 'SoftLayer.CLI.vlan.create:cli'),
+    ('vlan:create-options', 'SoftLayer.CLI.vlan.create_options:cli'),
     ('vlan:detail', 'SoftLayer.CLI.vlan.detail:cli'),
     ('vlan:edit', 'SoftLayer.CLI.vlan.edit:cli'),
     ('vlan:list', 'SoftLayer.CLI.vlan.list:cli'),
