@@ -14,7 +14,7 @@ getPrivateBlockDeviceTemplateGroups = [{
     'globalIdentifier': 'F9329795-4220-4B0A-B970-C86B950667FA',
     'id': 201,
     # 'name': 'private_image2',
-    'name': u'a¬ሴ€耀',
+    'name': 'a¬ሴ€耀',
     'parentId': '',
     'publicFlag': False,
 }]
@@ -1207,3 +1207,21 @@ getActiveVirtualLicenses = [{
         "version": 4
     }
 }]
+
+getBandwidthAllotments = [{
+    'billingCyclePublicBandwidthUsage': {
+        'amountIn': '6.94517',
+        'amountOut': '6.8859'
+    },
+    'id': 309961,
+    'locationGroup': {
+        'description': 'All Datacenters in Mexico',
+        'id': 262,
+        'locationGroupTypeId': 1,
+        'name': 'MEX',
+        'securityLevelId': None
+    },
+    'name': 'MexRegion',
+    'projectedPublicBandwidthUsage': 9.88,
+    'totalBandwidthAllocated': 3361
+}]
