@@ -8,16 +8,31 @@ getObject = {
         'id': 6327,
         'nextInvoiceTotalRecurringAmount': 1.54,
         'children': [
-            {'categoryCode': 'port_speed',
-             'nextInvoiceTotalRecurringAmount': 1},
-            {'categoryCode': 'guest_core',
-             'nextInvoiceTotalRecurringAmount': 1},
-            {'categoryCode': 'ram',
-             'nextInvoiceTotalRecurringAmount': 1},
-            {'categoryCode': 'guest_core',
-             'nextInvoiceTotalRecurringAmount': 1},
-            {'categoryCode': 'guest_disk1',
-             'nextInvoiceTotalRecurringAmount': 1},
+            {
+                'categoryCode': 'ram',
+                'description': '1 GB',
+                'nextInvoiceTotalRecurringAmount': 1
+            },
+            {
+                'categoryCode': 'remote_management',
+                'description': 'Reboot / Remote Console',
+                'nextInvoiceTotalRecurringAmount': 1
+            },
+            {
+                'categoryCode': 'port_speed',
+                'description': '1 Gbps Public & Private Network Uplinks',
+                'nextInvoiceTotalRecurringAmount': 1
+            },
+            {
+                'categoryCode': 'public_port',
+                'description': '1 Gbps Public Uplink',
+                'nextInvoiceTotalRecurringAmount': 1
+            },
+            {
+                'categoryCode': 'service_port',
+                'description': '1 Gbps Private Uplink',
+                'nextInvoiceTotalRecurringAmount': 1
+            }
         ],
         'package': {
             "id": 835,
@@ -28,7 +43,8 @@ getObject = {
                 'userRecord': {
                     'username': 'chechu',
                 }
-            }
+            },
+            'preset': {'keyName': 'B1_8X16X100'}
         }
     },
     'datacenter': {'id': 50, 'name': 'TEST00',
@@ -480,16 +496,16 @@ getCreateObjectOptions = {
             "categoryCode": "guest_disk0",
             "id": 81
         }}, {
-            "description": "250 GB (SAN)",
-            "attributes": [
-                {
-                    "id": 198,
-                    "attributeTypeKeyName": "SAN_DISK"
-                }],
-            "itemCategory": {
-                "categoryCode": "guest_disk0",
-                "id": 89
-            }}],
+        "description": "250 GB (SAN)",
+        "attributes": [
+            {
+                "id": 198,
+                "attributeTypeKeyName": "SAN_DISK"
+            }],
+        "itemCategory": {
+            "categoryCode": "guest_disk0",
+            "id": 89
+        }}],
     'guest_core': [{
         "description": "4 x 2.0 GHz or higher Cores (Dedicated)",
         "attributes": [],
@@ -497,13 +513,13 @@ getCreateObjectOptions = {
             "categoryCode": "guest_core",
             "id": 80
         }},
-                   {
-                       "description": "8 x 2.0 GHz or higher Cores",
-                       "attributes": [],
-                       "itemCategory": {
-                           "categoryCode": "guest_core",
-                           "id": 90
-                       }}]
+        {
+            "description": "8 x 2.0 GHz or higher Cores",
+            "attributes": [],
+            "itemCategory": {
+                "categoryCode": "guest_core",
+                "id": 90
+            }}]
 }
 
 getReverseDomainRecords = [{
@@ -875,3 +891,9 @@ getBlockDevices = [
 
 migrate = True
 migrateDedicatedHost = True
+allowAccessToNetworkStorageList = True
+
+attachDiskImage = {
+            "createDate": "2021-03-22T13:15:31-06:00",
+            "id": 1234567
+        }
