@@ -43,20 +43,25 @@ DEFAULT_VLAN_MASK = ','.join([
     'totalPrimaryIpAddressCount',
     'virtualGuestCount',
     'networkSpace',
+    'networkVlanFirewall[id,fullyQualifiedDomainName,primaryIpAddress]',
+    'attachedNetworkGateway[id,name,networkFirewall]',
 ])
 DEFAULT_GET_VLAN_MASK = ','.join([
     'firewallInterfaces',
     'primaryRouter[id, fullyQualifiedDomainName, datacenter]',
     'totalPrimaryIpAddressCount',
     'networkSpace',
+    'billingItem',
     'hardware',
     'subnets',
     'virtualGuests',
+    'networkVlanFirewall[id,fullyQualifiedDomainName,primaryIpAddress]',
+    'attachedNetworkGateway[id,name,networkFirewall]',
 ])
 
 
 class NetworkManager(object):
-    """Manage SoftLayer network objects: VLANs, subnets, IPs and rwhois
+    """Manage SoftLayer network objects: VLANs, subnets and IPs
 
     See product information here: https://www.ibm.com/cloud/network
 
@@ -311,34 +316,6 @@ class NetworkManager(object):
         return self.security_group.detachNetworkComponents(component_ids,
                                                            id=group_id)
 
-    def edit_rwhois(self, abuse_email=None, address1=None, address2=None,
-                    city=None, company_name=None, country=None,
-                    first_name=None, last_name=None, postal_code=None,
-                    private_residence=None, state=None):
-        """Edit rwhois record."""
-        update = {}
-        for key, value in [('abuseEmail', abuse_email),
-                           ('address1', address1),
-                           ('address2', address2),
-                           ('city', city),
-                           ('companyName', company_name),
-                           ('country', country),
-                           ('firstName', first_name),
-                           ('lastName', last_name),
-                           ('privateResidenceFlag', private_residence),
-                           ('state', state),
-                           ('postalCode', postal_code)]:
-            if value is not None:
-                update[key] = value
-
-        # If there's anything to update, update it
-        if update:
-            rwhois = self.get_rwhois()
-            return self.client['Network_Subnet_Rwhois_Data'].editObject(
-                update, id=rwhois['id'])
-
-        return True
-
     def edit_securitygroup(self, group_id, name=None, description=None):
         """Edit security group details.
 
@@ -408,13 +385,6 @@ class NetworkManager(object):
         obj = self.client['Network_Subnet_IpAddress']
         return obj.getByIpAddress(ip_address, mask='hardware, virtualGuest')
 
-    def get_rwhois(self):
-        """Returns the RWhois information about the current account.
-
-        :returns: A dictionary containing the account's RWhois information.
-        """
-        return self.account.getRwhoisData()
-
     def get_securitygroup(self, group_id, **kwargs):
         """Returns the information about the given security group.
 
@@ -787,3 +757,49 @@ class NetworkManager(object):
         """
         result = self.client.call('SoftLayer_Network_Subnet_IpAddress', 'editObject', note, id=identifier)
         return result
+
+    def get_cancel_failure_reasons(self, identifier):
+        """get the reasons why we cannot cancel the VLAN.
+
+        :param integer identifier:  the instance ID
+        """
+        return self.vlan.getCancelFailureReasons(id=identifier)
+
+    def cancel_item(self, identifier, cancel_immediately,
+                    reason_cancel, customer_note):
+        """Cancel a billing item immediately, deleting all its data.
+
+        :param integer identifier: the instance ID to cancel
+        :param string reason_cancel: reason cancel
+        """
+        return self.client.call('SoftLayer_Billing_Item', 'cancelItem',
+                                True,
+                                cancel_immediately,
+                                reason_cancel,
+                                customer_note,
+                                id=identifier)
+
+    def get_pods(self, datacenter=None):
+        """Calls SoftLayer_Network_Pod::getAllObjects()
+
+        returns list of all network pods and their routers.
+        """
+        _filter = None
+        if datacenter:
+            _filter = {"datacenterName": {"operation": datacenter}}
+
+        return self.client.call('SoftLayer_Network_Pod', 'getAllObjects', filter=_filter)
+
+    def get_list_datacenter(self):
+        """Calls SoftLayer_Location::getDatacenters()
+
+        returns all datacenter locations.
+        """
+        return self.client.call('SoftLayer_Location_Datacenter', 'getDatacenters')
+
+    def get_routers(self, identifier):
+        """Calls SoftLayer_Location::getRouters()
+
+        returns all routers locations.
+        """
+        return self.client.call('SoftLayer_Location_Datacenter', 'getHardwareRouters', id=identifier)
