@@ -17,7 +17,7 @@ ITEM_MASK = '''id, keyName, description, itemCategory, categories, prices'''
 
 PACKAGE_MASK = '''id, name, keyName, isActive, type'''
 
-PRESET_MASK = '''id, name, keyName, description'''
+PRESET_MASK = '''id, name, keyName, description, categories, prices, locations'''
 
 
 class OrderingManager(object):
@@ -169,6 +169,13 @@ class OrderingManager(object):
         quote = self.client['Billing_Order_Quote'].getObject(id=quote_id, mask=mask)
         return quote
 
+    def save_quote(self, quote_id):
+        """Save a quote.
+
+        :param quote_id: ID number of target quote
+        """
+        return self.client['Billing_Order_Quote'].saveQuote(id=quote_id)
+
     def get_order_container(self, quote_id):
         """Generate an order container from a quote object.
 
@@ -218,11 +225,11 @@ class OrderingManager(object):
         container = self.generate_order_template(quote_id, extra)
         clean_container = {}
 
-        # There are a few fields that wil cause exceptions in the XML endpoing if you send in ''
-        # reservedCapacityId and hostId specifically. But we clean all just to be safe.
+        # There are a few fields that wil cause exceptions in the XML endpoint if you send in '',
+        # or None in Rest endpoint (e.g. reservedCapacityId, hostId). But we clean all just to be safe.
         # This for some reason is only a problem on verify_quote.
         for key in container.keys():
-            if container.get(key) != '':
+            if container.get(key):
                 clean_container[key] = container[key]
 
         return self.client.call('SoftLayer_Billing_Order_Quote', 'verifyOrder', clean_container, id=quote_id)
